@@ -49,6 +49,9 @@ def main():
         diagram_file_path=diagram_path,
     )
 
+    print("Initializing Database...")
+    import flatland.Tests.build_db_test
+
     print("No problemo")
 
 
